@@ -45,15 +45,15 @@ class SearchString(Generic[Data]):
     True
     >>> arla_ss2.match('A text about Arla')
     True
-    >>> arla_ss1.match('The Europaen Parlament')
+    >>> arla_ss1.match('The European Parlament')
     True
-    >>> arla_ss2.match('The Europaen Parlament')
+    >>> arla_ss2.match('The European Parlament')
     False
     >>> arla_ss2.highlight('A text about Arla')
     'A text about <b>Arla</b>'
     """
     def __init__(self, first_str: str, second_str: str, not_str: str,
-                 data: Data):
+                 *, data: Data, third_str: Optional[str] = None):
         self.data = data
 
         search_str, first_str_global = self._preprocess_string(first_str)
@@ -64,6 +64,11 @@ class SearchString(Generic[Data]):
         self.second_str = search_str
         self.second_str_global = second_str_global
 
+        self.show_third_in_repr = third_str is not None
+        search_str, third_str_global = self._preprocess_string(third_str or '')
+        self.third_str = search_str
+        self.third_str_global = third_str_global
+
         search_str, not_str_global = self._preprocess_string(not_str)
         self.not_str = search_str
         self.not_str_global = not_str_global
@@ -72,7 +77,8 @@ class SearchString(Generic[Data]):
         self.any_global = any([
             first_str_global,
             second_str_global,
-            not_str_global
+            third_str_global,
+            not_str_global,
         ])
 
     def _escape_pattern(self, raw_pattern: str) -> Optional[str]:
@@ -171,6 +177,7 @@ class SearchString(Generic[Data]):
         is_match = (
             self._any_match(sentence, self.first_str)
             and self._any_match(sentence, self.second_str)
+            and self._any_match(sentence, self.third_str)
             and not self._any_match(sentence, self.not_str, empty_ret=False)
         )
         if is_match:
@@ -196,8 +203,8 @@ class SearchString(Generic[Data]):
         self._reset_matched_sentences()
 
         # Check, if needed, if there are any global matches
-        fst_global, snd_global, not_global \
-            = False, False, False
+        fst_global, snd_global, third_global, not_global \
+            = False, False, False, False
 
         if self.any_global:
             full_text = '\n\n'.join(sentences)
@@ -205,6 +212,8 @@ class SearchString(Generic[Data]):
                 fst_global = self._any_match(full_text, self.first_str)
             if self.second_str_global:
                 snd_global = self._any_match(full_text, self.second_str)
+            if self.third_str_global:
+                third_global = self._any_match(full_text, self.third_str)
             if self.not_str_global:
                 not_global = self._any_match(full_text, self.not_str,
                                              empty_ret=False)
@@ -217,6 +226,7 @@ class SearchString(Generic[Data]):
             is_match = (
                 (fst_global or self._any_match(sentence, self.first_str))
                 and (snd_global or self._any_match(sentence, self.second_str))
+                and (third_global or self._any_match(sentence, self.third_str))
                 and not (self._any_match(sentence, self.not_str,
                                          empty_ret=False))
             )
@@ -271,7 +281,7 @@ class SearchString(Generic[Data]):
         """
         try:
             subbed = text
-            for re_pattern in [self.first_str, self.second_str]:
+            for re_pattern in [self.first_str, self.second_str, self.third_str]:
                 if re_pattern:
                     subbed = re_pattern.sub(r'<b>\g<0></b>', subbed)
             return subbed
@@ -307,8 +317,13 @@ class SearchString(Generic[Data]):
         """
         first_str = self._pattern_to_str(self.first_str, self.first_str_global)
         second_str = self._pattern_to_str(self.second_str, self.second_str_global)
+        to_join = [first_str, second_str]
+        if self.show_third_in_repr:
+            third_str = self._pattern_to_str(self.third_str, self.third_str_global)
+            to_join.append(third_str)
         not_str = self._pattern_to_str(self.not_str, self.not_str_global)
-        return ', '.join([first_str, second_str, not_str])
+        to_join.append(not_str)
+        return ', '.join(to_join)
 
     def __str__(self) -> str:
         """
